/// <reference types="react" />
import { User, Session, SupabaseClient, Provider } from '@supabase/supabase-js';

interface AuthSession {
    user: User | null;
    session: Session | null;
}
interface Props {
    supabaseClient: SupabaseClient;
    [propName: string]: any;
}

type ThemeVariables = {
    colors?: {
        brand?: string;
        brandAccent?: string;
        brandButtonText?: string;
        defaultButtonBackground?: string;
        defaultButtonBackgroundHover?: string;
        defaultButtonBorder?: string;
        defaultButtonText?: string;
        dividerBackground?: string;
        inputBackground?: string;
        inputBorder?: string;
        inputBorderFocus?: string;
        inputBorderHover?: string;
        inputLabelText?: string;
        inputPlaceholder?: string;
        inputText?: string;
        messageText?: string;
        messageTextDanger?: string;
        anchorTextColor?: string;
        anchorTextHoverColor?: string;
    };
    space?: {
        spaceSmall?: string;
        spaceMedium?: string;
        spaceLarge?: string;
        labelBottomMargin?: string;
        anchorBottomMargin?: string;
        emailInputSpacing?: string;
        socialAuthSpacing?: string;
        buttonPadding?: string;
        inputPadding?: string;
    };
    fontSizes?: {
        baseBodySize?: string;
        baseInputSize?: string;
        baseLabelSize?: string;
        baseButtonSize?: string;
    };
    fonts?: {
        bodyFontFamily?: string;
        buttonFontFamily?: string;
        inputFontFamily?: string;
        labelFontFamily?: string;
    };
    borderWidths?: {
        buttonBorderWidth?: string;
        inputBorderWidth?: string;
    };
    radii?: {
        borderRadiusButton?: string;
        buttonBorderRadius?: string;
        inputBorderRadius?: string;
    };
};

type SocialLayout$1 = 'horizontal' | 'vertical';
type ViewSignIn$1 = 'sign_in';
type ViewSignUp$1 = 'sign_up';
interface Theme {
    default: ThemeVariables;
    [key: string]: ThemeVariables;
}
type RedirectTo$2 = undefined | string;
interface Appearance$1 {
    prependedClassName?: string;
    className?: {
        anchor?: string;
        button?: string;
        container?: string;
        divider?: string;
        input?: string;
        label?: string;
        loader?: string;
        message?: string;
    };
    style?: {
        anchor?: React.CSSProperties;
        button?: React.CSSProperties;
        container?: React.CSSProperties;
        divider?: React.CSSProperties;
        input?: React.CSSProperties;
        label?: React.CSSProperties;
        loader?: React.CSSProperties;
        message?: React.CSSProperties;
    };
}
type I18nVariables$1 = {
    sign_up?: {
        email_label?: string;
        password_label?: string;
        email_input_placeholder?: string;
        password_input_placeholder?: string;
        button_label?: string;
        social_provider_text?: string;
        link_text?: string;
    };
    sign_in?: {
        email_label?: string;
        password_label?: string;
        email_input_placeholder?: string;
        password_input_placeholder?: string;
        button_label?: string;
        social_provider_text?: string;
        link_text?: string;
    };
    magic_link?: {
        email_input_label?: string;
        email_input_placeholder?: string;
        button_label?: string;
        link_text?: string;
    };
    forgotten_password?: {
        email_label?: string;
        password_label?: string;
        email_input_placeholder?: string;
        button_label?: string;
        link_text?: string;
    };
    update_password?: {
        password_label?: string;
        password_input_placeholder?: string;
        button_label?: string;
    };
};

declare function MagicLink({ setAuthView, supabaseClient, redirectTo, i18n, appearance, showLinks, }: {
    setAuthView: any;
    supabaseClient: SupabaseClient;
    redirectTo?: RedirectTo$2;
    i18n: I18nVariables$1;
    appearance?: Appearance$1;
    showLinks?: boolean;
}): JSX.Element;
//# sourceMappingURL=MagicLink.d.ts.map

declare function UpdatePassword({ supabaseClient, i18n, appearance, }: {
    supabaseClient: SupabaseClient;
    i18n: I18nVariables$1;
    appearance?: Appearance$1;
}): JSX.Element;
//# sourceMappingURL=UpdatePassword.d.ts.map

declare function ForgottenPassword({ setAuthView, supabaseClient, redirectTo, i18n, appearance, showLinks, }: {
    setAuthView: any;
    supabaseClient: SupabaseClient;
    redirectTo?: RedirectTo$2;
    i18n: I18nVariables$1;
    appearance?: Appearance$1;
    showLinks?: boolean;
}): JSX.Element;
//# sourceMappingURL=ForgottenPassword.d.ts.map

type SocialLayout = 'horizontal' | 'vertical'

type ViewSignIn = 'sign_in'
type ViewSignUp = 'sign_up'
type ViewMagicLink = 'magic_link'
type ViewForgottenPassword = 'forgotten_password'
type ViewUpdatePassword = 'update_password'

type ViewType =
  | ViewSignIn
  | ViewSignUp
  | ViewMagicLink
  | ViewForgottenPassword
  | ViewUpdatePassword

type RedirectTo$1 = undefined | string

interface Appearance {
  prependedClassName?: string
  className?: {
    anchor?: string 
    button?: string 
    container?: string 
    divider?: string 
    input?: string 
    label?: string 
    loader?: string 
    message?: string 
  }
  style?: {
    anchor?: React.CSSProperties
    button?: React.CSSProperties
    container?: React.CSSProperties
    divider?: React.CSSProperties
    input?: React.CSSProperties
    label?: React.CSSProperties
    loader?: React.CSSProperties
    message?: React.CSSProperties
  }
}

interface Auth$1 {
  supabaseClient: SupabaseClient
  children?: React.ReactNode
  socialLayout?: SocialLayout
  providers?: Provider[]
  view?: ViewType
  redirectTo?: RedirectTo$1
  onlyThirdPartyProviders?: boolean
  magicLink?: boolean
  showLinks?: boolean

  /**
   * This will toggle on the dark variation of the theme
   */
  dark?: boolean
  /**
   * Override the labels and button text
   */
  localization?: {
    lang?: 'en' | 'ja' // es
    variables?: I18nVariables
  }
  appearance?: Appearance
  theme?: 'default' | 'minimal'
}

type I18nVariables = {
  sign_up?: {
    email_label?: string
    password_label?: string
    email_input_placeholder?: string
    password_input_placeholder?: string
    button_label?: string
    social_provider_text?: string
    link_text?: string
  }
  sign_in?: {
    email_label?: string
    password_label?: string
    email_input_placeholder?: string
    password_input_placeholder?: string
    button_label?: string
    social_provider_text?: string
    link_text?: string
  }
  magic_link?: {
    email_input_label?: string
    email_input_placeholder?: string
    button_label?: string
    link_text?: string
  }
  forgotten_password?: {
    email_label?: string
    password_label?: string
    email_input_placeholder?: string
    button_label?: string
    link_text?: string
  }
  update_password?: {
    password_label?: string
    password_input_placeholder?: string
    button_label?: string
  }
}

declare function Auth({ supabaseClient, socialLayout, providers, view, redirectTo, onlyThirdPartyProviders, magicLink, showLinks, appearance, theme, dark, localization, }: Auth$1): JSX.Element | null;
declare namespace Auth {
    var ForgottenPassword: typeof ForgottenPassword;
    var UpdatePassword: typeof UpdatePassword;
    var MagicLink: typeof MagicLink;
    var UserContextProvider: (props: Props) => JSX.Element;
    var useUser: () => AuthSession;
}
//# sourceMappingURL=Auth.d.ts.map

interface SocialAuthProps {
    supabaseClient: SupabaseClient;
    socialLayout: SocialLayout$1;
    providers?: Provider[];
    redirectTo: RedirectTo;
    onlyThirdPartyProviders: boolean;
    view: 'sign_in' | 'sign_up';
    i18n: I18nVariables$1;
    appearance?: Appearance$1;
}
type RedirectTo = undefined | string;
declare function SocialAuth({ supabaseClient, socialLayout, providers, redirectTo, onlyThirdPartyProviders, view, i18n, appearance, }: SocialAuthProps): JSX.Element;
//# sourceMappingURL=SocialAuth.d.ts.map

interface EmailAuthProps {
    authView: ViewSignIn$1 | ViewSignUp$1;
    defaultEmail: string;
    defaultPassword: string;
    setAuthView: any;
    setDefaultEmail: (email: string) => void;
    setDefaultPassword: (password: string) => void;
    supabaseClient: SupabaseClient;
    showLinks?: boolean;
    redirectTo?: RedirectTo$2;
    magicLink?: boolean;
    i18n: I18nVariables$1;
    appearance?: Appearance$1;
}
declare function EmailAuth({ authView, defaultEmail, defaultPassword, setAuthView, setDefaultEmail, setDefaultPassword, supabaseClient, showLinks, redirectTo, magicLink, i18n, appearance, }: EmailAuthProps): JSX.Element;

/**
 * Create default theme
 *
 * createStitches()
 * https://stitches.dev/docs/api#theme
 *
 * to add a new theme use  createTheme({})
 * https://stitches.dev/docs/api#theme
 */

declare const ThemeSupa: Theme;
declare const ThemeMinimal: Theme;

declare var de_formal = {
	sign_up: sign_up,
	sign_in: sign_in,
	magic_link: magic_link,
	forgotten_password: forgotten_password,
	update_password: update_password
};

declare var de_informal = {
	sign_up: sign_up,
	sign_in: sign_in,
	magic_link: magic_link,
	forgotten_password: forgotten_password,
	update_password: update_password
};

declare var en = {
	sign_up: sign_up,
	sign_in: sign_in,
	magic_link: magic_link,
	forgotten_password: forgotten_password,
	update_password: update_password
};

declare var ja = {
	sign_up: sign_up,
	sign_in: sign_in,
	magic_link: magic_link,
	forgotten_password: forgotten_password,
	update_password: update_password
};

export { Auth, EmailAuth, EmailAuthProps, ForgottenPassword, MagicLink, SocialAuth, ThemeMinimal, ThemeSupa, UpdatePassword, de_formal, de_informal, en, ja };
